@@ -1,6 +1,7 @@
 #' @title Calculating mean of technical replicates
 #' @description Calculating of technical replicates in and output table appropriate for subsequent ANOVA analysis
-#' @details The meanTech calculates mean of technical replicates.
+#' @details The meanTech calculates mean of technical replicates. Arithmetic mean of technical replicates can be calculated in order to 
+#' simplify the statistical comparison between sample groups.
 #' @author Ghader Mirzaghaderi
 #' @export meanTech
 #' @import tidyr
@@ -18,11 +19,14 @@
 #'
 #' # Calculating mean of technical replicates
 #' meanTech(data_withTechRep, groups = 1:4)
+#' 
+#' # Calculating mean of technical replicates
+#' meanTech(Lee_etal2020qPCR, groups = 1:3)
 #'
 #'
 
 meanTech <- function(x,
-                     groups = c(1:4)){
+                     groups){
 
   g <- colnames(x)[groups]
 
