@@ -11,7 +11,7 @@
 #' also affected by uncontrolled quantitative covariate(s). 
 #' For example, suppose that wDCt of a target gene in a plant is affected by temperature. The gene may 
 #' also be affected by drought. Since we already know that temperature affects the target gene, we are 
-#' interested to now if the gene expression is also altered by the drought levels. We can design an 
+#' interested to know if the gene expression is also altered by the drought levels. We can design an 
 #' experiment to understand the gene behavior at both temperature and drought levels at the same time. 
 #' The drought is another factor (the covariate) that may affect the expression of our gene under the 
 #' levels of the first factor i.e. temperature. The data of such an experiment can be analyzed by ANCOVA 
@@ -49,6 +49,7 @@
 #' @param fontsizePvalue font size of the pvalue labels
 #' @param axis.text.x.angle angle of x axis text
 #' @param axis.text.x.hjust horizontal justification of x axis text
+#' @param x.axis.labels.rename a vector replacing the x axis labels in the bar plot
 #' @param block column name of the block if there is a blocking factor (for correct column arrangement see example data.). When a qPCR experiment is done in multiple qPCR plates, variation resulting from the plates may interfere with the actual amount of gene expression. One solution is to conduct each plate as a complete randomized block so that at least one replicate of each treatment and control is present on a plate. Block effect is usually considered as random and its interaction with any main effect is not considered.
 #' @param p.adj Method for adjusting p values
 #' @return A list with 2 elements:
@@ -79,12 +80,12 @@
 #' # Data from Lee et al., 2020 
 #'
 #'df <- meanTech(Lee_etal2020qPCR, groups = 1:3)
-#'order2 <- unique(df$DS)
+#'order <- rev(unique(df$DS))
 #'qpcrANCOVA(df, 
 #'            numberOfrefGenes = 1, 
 #'            analysisType = "ancova", 
 #'            mainFactor.column = 2,
-#'            mainFactor.level.order = c("D7", "D12", "D15","D18"),
+#'            mainFactor.level.order = order,
 #'            fill = c("skyblue", "#BFEFFF"),
 #'            y.axis.adjust = 0.05)
 #' 
@@ -100,6 +101,27 @@
 #'           y.axis.adjust = 0.1)
 #'
 #'
+#'
+#' addline_format <- function(x,...){gsub('\\s','\n',x)}
+#' order <- unique(data_2factor$Drought)
+#' qpcrANCOVA(data_1factor,
+#'    numberOfrefGenes = 1,
+#'    mainFactor.column = 1,
+#'    mainFactor.level.order = c("L1","L2","L3"),
+#'    width = 0.5,
+#'    fill = c("skyblue","#79CDCD"),
+#'    y.axis.by = 1,
+#'    letter.position.adjust = 0,
+#'    y.axis.adjust = 1,
+#'    ylab = "Fold Change",
+#'    fontsize = 12,
+#'    x.axis.labels.rename = addline_format(c("Control", 
+#'                                          "Treatment_1 vs Control", 
+#'                                          "Treatment_2 vs Control")))
+#'                                                        
+#'                                                        
+
+
 
 qpcrANCOVA <- function(x,
                        numberOfrefGenes,
@@ -113,11 +135,12 @@ qpcrANCOVA <- function(x,
                        y.axis.by = 1,
                        letter.position.adjust = 0.1,
                        ylab = "Fold Change",
-                       xlab = "Pairs",
+                       xlab = "none",
                        fontsize = 12,
                        fontsizePvalue = 7,
                        axis.text.x.angle = 0,
                        axis.text.x.hjust = 0.5,
+                       x.axis.labels.rename = "none",
                        p.adj = "none"){
 
 
@@ -161,6 +184,7 @@ qpcrANCOVA <- function(x,
   
   
   
+  
   # Type of analysis: ancova or anova
   if (is.null(block)) {
     if(analysisType == "ancova") {
@@ -178,26 +202,24 @@ qpcrANCOVA <- function(x,
     } 
   }
   
-  
-  
+
+
   
   pp1 <- emmeans(lm, colnames(x)[1], data = x, adjust = p.adj)
-  pp <- as.data.frame(pairs(pp1), adjust = p.adj)
+  pp <- as.data.frame(graphics::pairs(pp1), adjust = p.adj)
   pp <- pp[1:length(mainFactor.level.order)-1,]
   
   
   # Preparing t-test results
   t_test_results <- list()
   
-  # t-tests for each level compared to the first level
   for (i in 2:length(mainFactor.level.order)) {
     level_data <- subset(x, x[,1] == mainFactor.level.order[i])$wDCt
     t_test_result <- stats::t.test(level_data, subset(x, x[,1] == mainFactor.level.order[1])$wDCt)
     t_test_results[[paste("t_test_result_", mainFactor.level.order[i], "_vs_", mainFactor.level.order[1])]] <- t_test_result
   }
   
-  # Extract the 95 percent confidence interval of each t-test
-  confidence_intervals <- data.frame(
+   confidence_intervals <- data.frame(
     Comparison = sapply(names(t_test_results), function(x) gsub("t_test_result_", "", x)),
     CI_lower = sapply(t_test_results, function(x) x$conf.int[1]),
     CI_upper = sapply(t_test_results, function(x) x$conf.int[2]),
@@ -238,8 +260,19 @@ qpcrANCOVA <- function(x,
   FINALDATA <- x
   tableC <- post_hoc_test
   
+  tableC$contrast <- sapply(strsplit(tableC$contrast, " - "), function(x) paste(rev(x), collapse = " vs "))
   
-  pairs <- tableC$contrast
+  if(any(x.axis.labels.rename == "none")){
+    tableC
+  }else{
+    tableC$contrast <- x.axis.labels.rename
+  }
+  
+  
+  
+  
+  tableC$contrast <- factor(tableC$contrast, levels = unique(tableC$contrast))
+  contrast <- tableC$contrast
   CI_lower <- tableC$CI_lower
   CI_upper <- tableC$CI_upper
   FCp <- as.numeric(tableC$FC)
@@ -248,16 +281,17 @@ qpcrANCOVA <- function(x,
   
   
   
+
   
-  pfc2 <- ggplot(tableC, aes(factor(pairs, levels = contrast), FCp, fill = pairs)) +
+  pfc2 <- ggplot(tableC, aes(contrast, FCp, fill = contrast)) +
     geom_col(col = "black", width = width) +
-    geom_errorbar(aes(pairs, ymin = FCp, ymax =  FCp + sddiff),
+    geom_errorbar(aes(contrast, ymin = FCp, ymax =  FCp + sddiff),
                   width=0.1) +
     geom_text(aes(label = significance,
-                  x = pairs,
+                  x = contrast,
                   y = FCp + sddiff + letter.position.adjust),
               vjust = -0.5, size = fontsizePvalue) +
-    ylab(ylab) + xlab(xlab) +
+    ylab(ylab) +
     theme_bw()+
     theme(axis.text.x = element_text(size = fontsize, color = "black", angle = axis.text.x.angle, hjust = axis.text.x.hjust),
           axis.text.y = element_text(size = fontsize, color = "black", angle = 0, hjust = 0.5),
@@ -267,7 +301,6 @@ qpcrANCOVA <- function(x,
     theme(legend.text = element_text(colour = "black", size = fontsize),
           legend.background = element_rect(fill = "transparent"))
   
-
   
   if(length(fill) == 2) {
     pfc2 <- pfc2 +
@@ -277,9 +310,37 @@ qpcrANCOVA <- function(x,
     pfc2 <- pfc2 +
       scale_fill_manual(values = rep(fill, nrow(tableC)))
   }
+  
   pfc2 <- pfc2 + guides(fill = "none") 
   
   
+  if(xlab == "none"){
+    pfc2 <- pfc2 + 
+      labs(x = NULL)
+  }else{
+    pfc2 <- pfc2 +
+    xlab(xlab)
+  }
+  
+  
+  
+  #changing as.factor(x) to x
+  lmf$coefficients <- gsub("as\\.factor\\(([^)]+)\\)", "\\1", lmf$coefficients)
+  lmf$coefficients <- gsub(":as factor", ":", lmf$coefficients)
+  
+  rownames(ANOVA) <- gsub("as\\.factor\\(([^)]+)\\)", "\\1", rownames(ANOVA))
+  rownames(ANOVA) <- gsub(":as factor", ":", rownames(ANOVA))
+  
+  lmc$coefficients <- gsub("as\\.factor\\(([^)]+)\\)", "\\1", lmc$coefficients)
+  lmc$coefficients <- gsub(":as factor", ":", lmc$coefficients)
+  
+  rownames(ANCOVA) <- gsub("as\\.factor\\(([^)]+)\\)", "\\1", rownames(ANCOVA))
+  rownames(ANCOVA) <- gsub(":as factor", ":", rownames(ANCOVA))
+  
+  
+  
+  
+  
   outlist2 <- list(Final_data = x,
                    lm_ANOVA = lmf,
                    lm_ANCOVA = lmc,
